@@ -10,6 +10,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"io/ioutil"
 	"net"
 	"reflect"
 	"sync"
@@ -123,7 +124,8 @@ func TestFraming(t *testing.T) {
 							continue
 						}
 
-						rbuf, err := io.ReadAll(r)
+						t.Logf("frame size: %d", n)
+						rbuf, err := ioutil.ReadAll(r)
 						if err != nil {
 							t.Errorf("%s: ReadFull() returned rbuf, %v", name, err)
 							continue
@@ -156,10 +158,7 @@ func TestControl(t *testing.T) {
 			wc := newTestConn(nil, &connBuf, isServer)
 			rc := newTestConn(&connBuf, nil, !isServer)
 			if isWriteControl {
-				if err := wc.WriteControl(PongMessage, []byte(message), time.Now().Add(time.Second)); err != nil {
-					t.Errorf("%s: wc.WriteControl() returned %v", name, err)
-					continue
-				}
+				wc.WriteControl(PongMessage, []byte(message), time.Now().Add(time.Second))
 			} else {
 				w, err := wc.NextWriter(PongMessage)
 				if err != nil {
@@ -176,9 +175,7 @@ func TestControl(t *testing.T) {
 				}
 				var actualMessage string
 				rc.SetPongHandler(func(s string) error { actualMessage = s; return nil })
-				if _, _, err := rc.NextReader(); err != nil {
-					continue
-				}
+				rc.NextReader()
 				if actualMessage != message {
 					t.Errorf("%s: pong=%q, want %q", name, actualMessage, message)
 					continue
@@ -362,19 +359,15 @@ func TestCloseFrameBeforeFinalMessageFrame(t *testing.T) {
 	rc := newTestConn(&b1, &b2, true)
 
 	w, _ := wc.NextWriter(BinaryMessage)
-	if _, err := w.Write(make([]byte, bufSize+bufSize/2)); err != nil {
-		t.Fatalf("w.Write() returned %v", err)
-	}
-	if err := wc.WriteControl(CloseMessage, FormatCloseMessage(expectedErr.Code, expectedErr.Text), time.Now().Add(10*time.Second)); err != nil {
-		t.Fatalf("wc.WriteControl() returned %v", err)
-	}
+	w.Write(make([]byte, bufSize+bufSize/2))
+	wc.WriteControl(CloseMessage, FormatCloseMessage(expectedErr.Code, expectedErr.Text), time.Now().Add(10*time.Second))
 	w.Close()
 
 	op, r, err := rc.NextReader()
 	if op != BinaryMessage || err != nil {
 		t.Fatalf("NextReader() returned %d, %v", op, err)
 	}
-	_, err = io.Copy(io.Discard, r)
+	_, err = io.Copy(ioutil.Discard, r)
 	if !reflect.DeepEqual(err, expectedErr) {
 		t.Fatalf("io.Copy() returned %v, want %v", err, expectedErr)
 	}
@@ -393,9 +386,7 @@ func TestEOFWithinFrame(t *testing.T) {
 		rc := newTestConn(&b, nil, true)
 
 		w, _ := wc.NextWriter(BinaryMessage)
-		if _, err := w.Write(make([]byte, bufSize)); err != nil {
-			t.Fatalf("%d: w.Write() returned %v", n, err)
-		}
+		w.Write(make([]byte, bufSize))
 		w.Close()
 
 		if n >= b.Len() {
@@ -410,7 +401,7 @@ func TestEOFWithinFrame(t *testing.T) {
 		if op != BinaryMessage || err != nil {
 			t.Fatalf("%d: NextReader() returned %d, %v", n, op, err)
 		}
-		_, err = io.Copy(io.Discard, r)
+		_, err = io.Copy(ioutil.Discard, r)
 		if err != errUnexpectedEOF {
 			t.Fatalf("%d: io.Copy() returned %v, want %v", n, err, errUnexpectedEOF)
 		}
@@ -429,15 +420,13 @@ func TestEOFBeforeFinalFrame(t *testing.T) {
 	rc := newTestConn(&b1, &b2, true)
 
 	w, _ := wc.NextWriter(BinaryMessage)
-	if _, err := w.Write(make([]byte, bufSize+bufSize/2)); err != nil {
-		t.Fatalf("w.Write() returned %v", err)
-	}
+	w.Write(make([]byte, bufSize+bufSize/2))
 
 	op, r, err := rc.NextReader()
 	if op != BinaryMessage || err != nil {
 		t.Fatalf("NextReader() returned %d, %v", op, err)
 	}
-	_, err = io.Copy(io.Discard, r)
+	_, err = io.Copy(ioutil.Discard, r)
 	if err != errUnexpectedEOF {
 		t.Fatalf("io.Copy() returned %v, want %v", err, errUnexpectedEOF)
 	}
@@ -450,9 +439,7 @@ func TestEOFBeforeFinalFrame(t *testing.T) {
 func TestWriteAfterMessageWriterClose(t *testing.T) {
 	wc := newTestConn(nil, &bytes.Buffer{}, false)
 	w, _ := wc.NextWriter(BinaryMessage)
-	if _, err := io.WriteString(w, "hello"); err != nil {
-		t.Fatalf("unexpected error writing, %v", err)
-	}
+	io.WriteString(w, "hello")
 	if err := w.Close(); err != nil {
 		t.Fatalf("unxpected error closing message writer, %v", err)
 	}
@@ -462,9 +449,7 @@ func TestWriteAfterMessageWriterClose(t *testing.T) {
 	}
 
 	w, _ = wc.NextWriter(BinaryMessage)
-	if _, err := io.WriteString(w, "hello"); err != nil {
-		t.Fatalf("unexpected error writing after getting new writer, %v", err)
-	}
+	io.WriteString(w, "hello")
 
 	// close w by getting next writer
 	_, err := wc.NextWriter(BinaryMessage)
@@ -489,21 +474,13 @@ func TestReadLimit(t *testing.T) {
 
 		// Send message at the limit with interleaved pong.
 		w, _ := wc.NextWriter(BinaryMessage)
-		if _, err := w.Write(message[:readLimit-1]); err != nil {
-			t.Fatalf("w.WriteMessage() returned %v", err)
-		}
-		if err := wc.WriteControl(PongMessage, []byte("this is a pong"), time.Now().Add(10*time.Second)); err != nil {
-			t.Fatalf("wc.WriteControl() returned %v", err)
-		}
-		if _, err := w.Write(message[:1]); err != nil {
-			t.Fatalf("w.Write() returned %v", err)
-		}
+		w.Write(message[:readLimit-1])
+		wc.WriteControl(PongMessage, []byte("this is a pong"), time.Now().Add(10*time.Second))
+		w.Write(message[:1])
 		w.Close()
 
 		// Send message larger than the limit.
-		if err := wc.WriteMessage(BinaryMessage, message[:readLimit+1]); err != nil {
-			t.Fatalf("wc.WriteMessage() returned %v", err)
-		}
+		wc.WriteMessage(BinaryMessage, message[:readLimit+1])
 
 		op, _, err := rc.NextReader()
 		if op != BinaryMessage || err != nil {
@@ -513,7 +490,7 @@ func TestReadLimit(t *testing.T) {
 		if op != BinaryMessage || err != nil {
 			t.Fatalf("2: NextReader() returned %d, %v", op, err)
 		}
-		_, err = io.Copy(io.Discard, r)
+		_, err = io.Copy(ioutil.Discard, r)
 		if err != ErrReadLimit {
 			t.Fatalf("io.Copy() returned %v", err)
 		}
@@ -616,9 +593,7 @@ func TestBufioReadBytes(t *testing.T) {
 	rc := newConn(fakeNetConn{Reader: &b1, Writer: &b2}, true, len(m)-64, len(m)-64, nil, nil, nil)
 
 	w, _ := wc.NextWriter(BinaryMessage)
-	if _, err := w.Write(m); err != nil {
-		t.Fatalf("w.Write() returned %v", err)
-	}
+	w.Write(m)
 	w.Close()
 
 	op, r, err := rc.NextReader()
@@ -692,9 +667,7 @@ func TestConcurrentWritePanic(t *testing.T) {
 	w := blockingWriter{make(chan struct{}), make(chan struct{})}
 	c := newTestConn(nil, w, false)
 	go func() {
-		if err := c.WriteMessage(TextMessage, []byte{}); err != nil {
-			t.Error(err)
-		}
+		c.WriteMessage(TextMessage, []byte{})
 	}()
 
 	// wait for goroutine to block in write.
@@ -707,9 +680,7 @@ func TestConcurrentWritePanic(t *testing.T) {
 		}
 	}()
 
-	if err := c.WriteMessage(TextMessage, []byte{}); err != nil {
-		t.Error(err)
-	}
+	c.WriteMessage(TextMessage, []byte{})
 	t.Fatal("should not get here")
 }
 
@@ -729,7 +700,7 @@ func TestFailedConnectionReadPanic(t *testing.T) {
 	}()
 
 	for i := 0; i < 20000; i++ {
-		_, _, _ = c.ReadMessage()
+		c.ReadMessage()
 	}
 	t.Fatal("should not get here")
 }
